Package: mcmsupply
Type: Package
Title: Estimating Public and Private Sector Contraceptive Market Supply
        Shares
Version: 1.1.1
Authors@R: 
    c(person("Hannah", "Comiskey", email="hannah.comiskey.2015@mumail.ie", 
    role = c("aut", "cre")),
    person("Niamh", "Cahill", role = "aut"),
    person("Leontine", "Alkema", role ="aut"))
Description: Family Planning programs and initiatives typically use nationally representative surveys to estimate key indicators of a country’s family planning progress. However, in recent years, routinely collected family planning services data (Service Statistics) have been used as a supplementary data source to bridge gaps in the surveys. The use of service statistics comes with the caveat that adjustments need to be made for missing private sector contributions to the contraceptive method supply chain. Evaluating the supply source of modern contraceptives often relies on Demographic Health Surveys (DHS), where many countries do not have recent data beyond 2015/16. Fortunately, in the absence of recent surveys we can rely on statistical model-based estimates and projections to fill the knowledge gap. We present a Bayesian, hierarchical, penalized-spline model with multivariate-normal spline coefficients, to account for across method correlations, to produce country-specific,annual estimates for the proportion of modern contraceptive methods coming from the public and private sectors. This package provides a quick and convenient way for users to access the DHS modern contraceptive supply share data at national and subnational administration levels, estimate, evaluate and plot annual estimates with uncertainty for a sample of low- and middle-income countries. Methods for the estimation of method supply shares at the national level are described in Comiskey, Alkema, Cahill (2022) <arXiv:2212.03844>.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5.0)
RoxygenNote: 7.2.3
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Imports: R2jags, magrittr, foreach, tidyverse, tidybayes, runjags,
        stats, rlang, abind, dplyr, ggplot2, plyr, readxl, stringr,
        tibble, tidyr
URL: https://hannahcomiskey.github.io/mcmsupply/,
        https://hannahcomiskey.github.io/mcmsupply/
NeedsCompilation: no
Packaged: 2024-03-15 15:50:52 UTC; hannahcomiskey
Author: Hannah Comiskey [aut, cre],
  Niamh Cahill [aut],
  Leontine Alkema [aut]
Maintainer: Hannah Comiskey <hannah.comiskey.2015@mumail.ie>
Repository: CRAN
Date/Publication: 2024-03-18 15:50:02 UTC
Built: R 4.2.3; ; 2024-03-18 16:38:26 UTC; unix
